package net.wanji.opt.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.dto.trend.GreenwaveListDTO;
import net.wanji.opt.service.impl.TrendServiceImpl;
import net.wanji.opt.vo.GreenwaveListVO;
import net.wanji.opt.vo.GreenwaveStats;
import net.wanji.opt.vo.GreenwaveVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.util.List;

/**
 * 态势监测
 *
 * @author Kent HAN
 */
@Api(value = "TrendController", description = "态势监测")
@RequestMapping("/trend")
@RestController
public class TrendController {
    private final TrendServiceImpl trendService;

    public TrendController(TrendServiceImpl trendService) {
        this.trendService = trendService;
    }

    @ApiOperation(value = "问题子区列表", notes = "问题子区列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenwaveList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveVO.class),
    })
    public JsonViewObject greenwaveList(@RequestBody GreenwaveListDTO greenwaveListDTO) {
        GreenwaveVO greenwaveVO = new GreenwaveVO();
        List<GreenwaveListVO> greenwaveListVOList = trendService.greenwaveList(greenwaveListDTO);
        greenwaveVO.setGreenwaveList(greenwaveListVOList);
        // 绿波统计信息
        GreenwaveStats greenwaveStats = trendService.buildGreenwaveStats(greenwaveListVOList);
        greenwaveVO.setGreenwaveStats(greenwaveStats);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(greenwaveVO);
    }
}